==> edc_he-0.1.7-py3-none-any.whl: edc_he/model_mixins/patient_model_mixin.py <==
from django.db import models
from edc_constants.choices import YES_NO
from edc_model_fields.fields import OtherCharField

from ..choices import (
    EDUCATION_CHOICES,
    EMPLOYMENT_CHOICES,
    EMPLOYMENT_STATUS_CHOICES,
    ETHNICITY_CHOICES,
    MARITAL_CHOICES,
    RELIGION_CHOICES,
)
from ..models import InsuranceTypes


class PatientModelMixin(models.Model):
    pat_citizen = models.CharField(
        verbose_name="Is the patient a citizen of this country?",
        max_length=15,
        choices=YES_NO,
    )

    pat_religion = models.CharField(
        verbose_name="How would you describe your religious orientation?",
        max_length=25,
        choices=RELIGION_CHOICES,
    )

    pat_religion_other = OtherCharField(
        verbose_name="If OTHER religious orientation, specify ...",
    )

    pat_ethnicity = models.CharField(
        verbose_name="What is your ethnic background?",
        max_length=25,
        choices=ETHNICITY_CHOICES,
    )

    pat_ethnicity_other = OtherCharField(
        verbose_name="If OTHER ethnic background, specify ...",
    )

    pat_education = models.CharField(
        verbose_name="Highest level of education completed?",
        max_length=25,
        choices=EDUCATION_CHOICES,
    )
    pat_education_other = OtherCharField(
        verbose_name="If OTHER level of education, specify ...",
    )

    pat_employment = models.CharField(
        verbose_name="What is your employment status?",
        max_length=25,
        choices=EMPLOYMENT_STATUS_CHOICES,
    )

    pat_employment_type = models.CharField(
        verbose_name="What is your type of employment?",
        max_length=25,
        choices=EMPLOYMENT_CHOICES,
    )

    pat_marital_status = models.CharField(
        verbose_name="What is your marital status?",
        max_length=25,
        choices=MARITAL_CHOICES,
    )
    pat_marital_status_other = OtherCharField(
        verbose_name="If OTHER marital status, specify ...",
    )

    pat_insurance = models.ManyToManyField(
        InsuranceTypes,
        related_name="patinsurancetypes",
        verbose_name="What is your health insurance status?",
    )

    pat_insurance_other = OtherCharField(
        verbose_name="If OTHER health insurance status, specify ...",
    )

    class Meta:
        abstract = True

==> edc_he-0.1.11-py3-none-any.whl: edc_he/model_mixins/patient_model_mixin.py <==
from django.db import models
from django.db.models import PROTECT
from edc_constants.choices import YES_NO
from edc_model_fields.fields import OtherCharField

from ..choices import EMPLOYMENT_STATUS_CHOICES, MARITAL_CHOICES


class PatientModelMixin(models.Model):
    pat_citizen = models.CharField(
        verbose_name="Is the patient a citizen of this country?",
        max_length=15,
        choices=YES_NO,
        null=True,
    )

    pat_religion = models.ForeignKey(
        "edc_he.religions",
        verbose_name="How would you describe your religious orientation?",
        related_name="+",
        on_delete=PROTECT,
        null=True,
        blank=False,
    )

    pat_religion_other = OtherCharField(
        verbose_name="If OTHER religious orientation, specify ...",
    )

    pat_ethnicity = models.ForeignKey(
        "edc_he.ethnicities",
        verbose_name="What is your ethnic background?",
        related_name="+",
        on_delete=PROTECT,
        null=True,
        blank=False,
    )

    pat_ethnicity_other = OtherCharField(
        verbose_name="If OTHER ethnic background, specify ...",
    )

    pat_education = models.ForeignKey(
        "edc_he.education",
        verbose_name="Highest level of education completed?",
        related_name="+",
        on_delete=PROTECT,
        null=True,
        blank=False,
    )

    pat_education_other = OtherCharField(
        verbose_name="If OTHER level of education, specify ...",
    )

    pat_employment_status = models.CharField(
        verbose_name="What is your employment status?",
        max_length=25,
        choices=EMPLOYMENT_STATUS_CHOICES,
    )

    pat_employment_type = models.ForeignKey(
        "edc_he.employmenttype",
        verbose_name="What is your type of employment?",
        related_name="+",
        on_delete=PROTECT,
        null=True,
        blank=False,
    )

    pat_employment_type_other = OtherCharField(
        verbose_name="If OTHER type of employment, specify ...",
        max_length=100,
    )

    pat_marital_status = models.CharField(
        verbose_name="What is your marital status?",
        max_length=25,
        choices=MARITAL_CHOICES,
    )
    pat_marital_status_other = OtherCharField(
        verbose_name="If OTHER marital status, specify ...",
    )

    pat_insurance = models.ManyToManyField(
        "edc_he.insurancetypes",
        verbose_name="What is your health insurance status?",
        related_name="+",
    )

    pat_insurance_other = OtherCharField(
        verbose_name="If OTHER health insurance status, specify ...",
    )

    # not used
    pat_ethnicity_old = models.CharField(
        verbose_name="What is your ethnic background?",
        max_length=25,
    )

    # not used
    pat_employment_type_old = models.CharField(
        verbose_name="What is your type of employment?",
        max_length=25,
    )

    # not used
    pat_education_old = models.CharField(
        verbose_name="Highest level of education completed?",
        max_length=25,
    )

    # not used
    pat_religion_old = models.CharField(
        verbose_name="How would you describe your religious orientation?",
        max_length=25,
    )

    class Meta:
        abstract = True
